#!/bin/bash

# Ensure the script is run as root
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi

# Check if the binary exists
if [ ! -f "./ProVideGateway" ]; then
    echo "Error: ProVideGateway binary not found!"
    exit 1
fi

# check if process is running
PROCESS_NAME="ProVideGateway"
# Check if process is running
if pgrep -x "$PROCESS_NAME" > /dev/null; then
    echo "$PROCESS_NAME is currently running."
    
    # Ask to stop the process
    read -p "Do you want to stop the process? ([Y]es/[N]o): " response
    
    # Enable case-insensitive matching
    shopt -s nocasematch
    
    if [[ "$response" == "yes" || "$response" == "y" ]]; then
        # Kill the process
        pkill -x "$PROCESS_NAME"
        echo "$PROCESS_NAME has been stopped."
    elif [[ "$response" == "no" || "$response" == "n" ]]; then
        echo "The process must be stopped to continue."
        exit 1
    else
        echo "Invalid input. Please enter 'yes', 'no', 'y', or 'n'."
        exit 1
    fi
    
    # Disable case-insensitive matching
    shopt -u nocasematch
else
    echo "$PROCESS_NAME is not running. Continuing..."
fi

# Copy the binary and set permissions
cp ./ProVideGateway /usr/bin/ProVideGateway
chmod 755 /usr/bin/ProVideGateway

# Check if the systemd service already exists
SERVICE_FILE="/etc/systemd/system/providegateway.service"
if [ -f "$SERVICE_FILE" ]; then
    echo "Warning: ProVideGateway service already exists. Creating a backup."
    cp "$SERVICE_FILE" "${SERVICE_FILE}.bak"
fi

# Create a new systemd service file
cat <<EOF > "$SERVICE_FILE"
[Unit]
Description=ProVide Gateway
After=network.target
StartLimitIntervalSec=30
StartLimitBurst=5

[Service]
Type=forking
Restart=on-failure
RestartSec=5
ExecStart=/usr/bin/ProVideGateway

[Install]
WantedBy=multi-user.target
EOF

# Reload systemd to acknowledge changes
systemctl daemon-reload

# Enable and start the service
systemctl enable providegateway.service
if systemctl start providegateway.service; then
    echo "ProVideGateway service started successfully."
else
    echo "Failed to start ProVideGateway service."
    exit 1
fi
