#!/bin/bash
# Script disables service and removes ProVideGateway
# Ensure the script is run as root

if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi

# check if process is running
PROCESS_NAME="ProVideGateway"
# Check if process is running
if pgrep -x "$PROCESS_NAME" > /dev/null; then
    echo "$PROCESS_NAME is currently running."
    
    # Ask to stop the process
    read -p "Do you want to stop the process? ([Y]es/[N]o): " response
    
    # Enable case-insensitive matching
    shopt -s nocasematch
    
    if [[ "$response" == "yes" || "$response" == "y" ]]; then
        # Kill the process
        pkill -x "$PROCESS_NAME"
        echo "$PROCESS_NAME has been stopped."
    elif [[ "$response" == "no" || "$response" == "n" ]]; then
        echo "The process must be stopped to continue."
        exit 1
    else
        echo "Invalid input. Please enter 'yes', 'no', 'y', or 'n'."
        exit 1
    fi
    
    # Disable case-insensitive matching (optional)
    shopt -u nocasematch
else
    echo "$PROCESS_NAME is not running. Continuing..."
fi

# Check if the systemd service exists
SERVICE_FILE="/etc/systemd/system/providegateway.service"
if [ -f "$SERVICE_FILE" ]; then
    systemctl disable providegateway.service && rm $SERVICE_FILE && systemctl daemon-reload
    echo "ProVideGateway Service removed"
else 
    echo "No ProvideGateway Service located"
    exit 1
fi

# Check for binary and remove binary
BINARY_FILE="/usr/bin/ProVideGateway"
if [ -f "$BINARY_FILE" ]; then
    rm $BINARY_FILE
    echo "ProVide Gateway uninstalled"
else
    echo "No binary located"
    exit 1
fi
